@@ -1,24 +1,17 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitCommaSeparatedStatements.pm $
-#     $Date: 2009-03-07 09:14:51 -0600 (Sat, 07 Mar 2009) $
-#   $Author: clonezone $
-# $Revision: 3231 $
-##############################################################################
-
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitCommaSeparatedStatements;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 
-use Perl::Critic::Utils qw{ :booleans :characters :severities :classification };
+use Perl::Critic::Utils qw{ :booleans :characters :severities :classification hashify };
 use Perl::Critic::Utils::PPI qw{ is_ppi_statement_subclass };
 
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.098';
+our $VERSION = '1.152';
 
 #-----------------------------------------------------------------------------
 
@@ -39,7 +32,7 @@ sub supported_parameters {
 }
 
 sub default_severity     { return $SEVERITY_HIGH      }
-sub default_themes       { return qw( core bugs pbp ) }
+sub default_themes       { return qw( core bugs pbp certrule ) }
 sub applies_to           { return 'PPI::Statement'    }
 
 #-----------------------------------------------------------------------------
@@ -101,7 +94,7 @@ sub _is_parent_a_for_loop {
 
     return if not $parent;
 
-    return if not $parent->isa('PPI::Structure::ForLoop');
+    return if not $parent->isa('PPI::Structure::For');
 
     return 1 == scalar $parent->schildren(); # Multiple means C-style loop.
 }
@@ -117,7 +110,8 @@ sub _is_direct_part_of_map_or_grep_block {
     return if not $block_prior_sibling;
     return if not $block_prior_sibling->isa('PPI::Token::Word');
 
-    return $block_prior_sibling eq 'map' || $block_prior_sibling eq 'grep';
+    state $is_map_or_grep = { hashify( qw( map grep ) ) };
+    return $is_map_or_grep->{$block_prior_sibling};
 }
 
 sub _is_last_statement_in_a_block {
@@ -242,7 +236,7 @@ Elliot Shank C<< <perl@galumph.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2023 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
